@@ -83,6 +83,8 @@ static void move_current_tab_to_another_notebook  (PlumaNotebook  *src,
 /* Local variables */
 static GdkCursor *cursor = NULL;
 static gboolean leftdown = FALSE;
+static gboolean drag_ready = FALSE;
+static gboolean newfile_ready = TRUE;
 
 /* Signals */
 enum
@@ -482,7 +484,11 @@ motion_notify_cb (PlumaNotebook  *notebook,
 					      event->x_root, 
 					      event->y_root))
 		{
-			drag_start (notebook, event->time);
+			if (drag_ready)
+				drag_start (notebook, event->time);
+			else
+				drag_stop (notebook);
+
 			return TRUE;
 		}
 
@@ -592,6 +598,7 @@ button_release_cb (PlumaNotebook  *notebook,
 
 	/* This must be called even if a drag isn't happening */
 	drag_stop (notebook);
+	drag_ready = FALSE;
 
 	return FALSE;
 }
@@ -617,8 +624,6 @@ button_press_cb (PlumaNotebook  *notebook,
 	    (event->type == GDK_BUTTON_PRESS) && 
 	    (tab_clicked >= 0))
 	{
-		leftdown = TRUE;
-
 		notebook->priv->x_start = event->x_root;
 		notebook->priv->y_start = event->y_root;
 		
@@ -658,21 +663,54 @@ button_press_cb (PlumaNotebook  *notebook,
 		if (event->type == GDK_BUTTON_PRESS)
 		{
 			tab1click = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
-			newfile = (tab_clicked == -1);
+
+			if (newfile_ready)
+				newfile = (tab_clicked == -1);
+			else
+				newfile = FALSE;
 		}
 		else if (event->type == GDK_2BUTTON_PRESS)
 		{
 			if ((tab1click != gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook))) ||
-			    (tab_clicked >= 0) || ((tab_clicked == -1) && (!newfile)))
+			    (tab_clicked >= 0) || ((tab_clicked == -1) && (!newfile)) || (!leftdown))
 				return TRUE;
 
 			newfile = FALSE;
 		}
+
+	leftdown = TRUE;
 	}
 
 	return FALSE;
 }
 
+static gboolean
+grab_focus_cb (PlumaNotebook  *notebook,
+	       GdkEventButton *event,
+	       gpointer        data)
+{
+	drag_ready = TRUE;
+	return FALSE;
+}
+
+static gboolean
+focus_in_cb (PlumaNotebook  *notebook,
+	     GdkEventButton *event,
+	     gpointer        data)
+{
+	newfile_ready = FALSE;
+	return FALSE;
+}
+
+static gboolean
+focus_out_cb (PlumaNotebook  *notebook,
+	      GdkEventButton *event,
+	      gpointer        data)
+{
+	newfile_ready = TRUE;
+	return FALSE;
+}
+
 /**
  * pluma_notebook_new:
  *
@@ -763,10 +801,27 @@ pluma_notebook_init (PlumaNotebook *notebook)
 			  "button-press-event",
 			  (GCallback)button_press_cb, 
 			  NULL);
+
 	g_signal_connect (notebook, 
 			  "button-release-event",
 			  (GCallback)button_release_cb,
 			  NULL);
+
+	g_signal_connect (notebook, 
+			  "grab-focus",
+			  (GCallback)grab_focus_cb,
+			  NULL);
+
+	g_signal_connect (notebook, 
+			  "focus-in-event",
+			  (GCallback)focus_in_cb,
+			  NULL);
+
+	g_signal_connect (notebook, 
+			  "focus-out-event",
+			  (GCallback)focus_out_cb,
+			  NULL);
+
 	gtk_widget_add_events (GTK_WIDGET (notebook), 
 			       GDK_BUTTON1_MOTION_MASK);
 
@@ -838,16 +893,6 @@ close_button_clicked_cb (PlumaTabLabel *tab_label, PlumaNotebook *notebook)
 	g_signal_emit (notebook, signals[TAB_CLOSE_REQUEST], 0, tab);
 }
 
-static gboolean
-tab_label_scroll_cb (PlumaTabLabel  *tab_label,
-                     GdkEventScroll *event,
-                     PlumaNotebook  *notebook)
-{
-	g_signal_emit_by_name (notebook, "scroll-event", &event);
-	
-	return FALSE;
-}
-
 static GtkWidget *
 create_tab_label (PlumaNotebook *nb,
 		  PlumaTab      *tab)
@@ -860,10 +905,6 @@ create_tab_label (PlumaNotebook *nb,
 			  "close-clicked",
 			  G_CALLBACK (close_button_clicked_cb),
 			  nb);
-	g_signal_connect (tab_label,
-			  "scroll-event",
-			  G_CALLBACK (tab_label_scroll_cb),
-			  nb);
 
 	g_object_set_data (G_OBJECT (tab), "tab-label", tab_label);
 
